@@ -59,7 +59,7 @@ CommandUtils::CommandUtils(TCanvasItem* item)
     c = m_canvas_item->canvas();
     /* NOT NEEDED:
     if( m_canvas_item && m_canvas_item->item() )
-        connect( m_canvas_item->item(), TQT_SIGNAL( destroyed() ), this, TQT_SLOT( documentItemDeleted() ) );
+        connect( m_canvas_item->item(), TQ_SIGNAL( destroyed() ), this, TQ_SLOT( documentItemDeleted() ) );
     */
 }
 
@@ -125,7 +125,7 @@ void NewItemCommand::execute()
 	    m_item->addRef();
 
 	    /* NOT NEEDED:
-            connect( m_object, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( documentItemDeleted() ) );
+            connect( m_object, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( documentItemDeleted() ) );
 	    */
         }
     }
@@ -506,7 +506,7 @@ DeleteCommand::~DeleteCommand()
     {
         DocumentItem* item = m_canvas_item->item();
         if( item )
-            item->disconnect( item, TQT_SIGNAL( destroyed() ), this, 0 );
+            item->disconnect( item, TQ_SIGNAL( destroyed() ), this, 0 );
         delete m_canvas_item;
     }
 }
