@@ -207,19 +207,19 @@ DefinitionDialog::DefinitionDialog( TQWidget* parent,  const char* name, bool mo
 
     l = new TQLabel( this );
     setExtension( l );
-    setOrientation(Qt::Vertical );
+    setOrientation(TQt::Vertical );
 
-    connect( buttonCancel, TQT_SIGNAL( clicked() ), this, TQT_SLOT( reject() ) );
-    connect( buttonAdd, TQT_SIGNAL( clicked() ), this, TQT_SLOT( add() ) );
+    connect( buttonCancel, TQ_SIGNAL( clicked() ), this, TQ_SLOT( reject() ) );
+    connect( buttonAdd, TQ_SIGNAL( clicked() ), this, TQ_SLOT( add() ) );
 
-    connect( editWidth, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( updatePreview() ) );
-    connect( editHeight, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( updatePreview() ) );
-    connect( editHGap, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( updatePreview() ) );
-    connect( editVGap, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( updatePreview() ) );
-    connect( editTGap, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( updatePreview() ) );
-    connect( editLGap, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( updatePreview() ) );
-    connect( editNumH, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( updatePreview() ) );
-    connect( editNumV, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( updatePreview() ) );
+    connect( editWidth, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( updatePreview() ) );
+    connect( editHeight, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( updatePreview() ) );
+    connect( editHGap, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( updatePreview() ) );
+    connect( editVGap, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( updatePreview() ) );
+    connect( editTGap, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( updatePreview() ) );
+    connect( editLGap, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( updatePreview() ) );
+    connect( editNumH, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( updatePreview() ) );
+    connect( editNumV, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( updatePreview() ) );
 
     comboProducer->setInsertionPolicy( TQComboBox::NoInsertion );
     comboType->setInsertionPolicy( TQComboBox::NoInsertion );
@@ -232,9 +232,9 @@ DefinitionDialog::DefinitionDialog( TQWidget* parent,  const char* name, bool mo
     for( unsigned int i = 0; i < list.count(); i++ )
         types[i] = Definition::getTypes( list[i] );
 
-    connect( comboProducer, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( updateType() ) );
-    connect( comboType, TQT_SIGNAL( textChanged(const TQString &) ), this, TQT_SLOT( updateText() ) );
-    connect( buttonInfo, TQT_SIGNAL( clicked() ), this, TQT_SLOT( toggleExtension() ) );
+    connect( comboProducer, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( updateType() ) );
+    connect( comboType, TQ_SIGNAL( textChanged(const TQString &) ), this, TQ_SLOT( updateText() ) );
+    connect( buttonInfo, TQ_SIGNAL( clicked() ), this, TQ_SLOT( toggleExtension() ) );
 
     drawGraphic();
     updateType();
