@@ -20,7 +20,7 @@ class TQPaintEvent;
   * The labels are drawn using TQPainter. Only one page is previewed.
   */
 class LabelPreview : public TQWidget {
-    Q_OBJECT
+    TQ_OBJECT
   
     public:
         LabelPreview( TQWidget* parent = 0, const char* name = 0 );
@@ -44,7 +44,7 @@ class LabelPreview : public TQWidget {
   */
 class DefinitionDialog : public TQDialog
 { 
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
