@@ -54,7 +54,7 @@ NewLabel::NewLabel( TQWidget* parent,  const char* name, bool change, WFlags fl
 
     TQGroupBox* group1 = new TQGroupBox( this );
     group1->setTitle( i18n( "Label" ) );
-    group1->setColumnLayout(0, Qt::Vertical );
+    group1->setColumnLayout(0, TQt::Vertical );
     group1->layout()->setSpacing( 6 );
     group1->layout()->setMargin( 11 );
     TQGridLayout* group1Layout = new TQGridLayout( group1->layout() );
@@ -115,14 +115,14 @@ NewLabel::NewLabel( TQWidget* parent,  const char* name, bool change, WFlags fl
     Layout1->addWidget( buttonCancel );
     NewLabelLayout->addLayout( Layout1 );
 
-    connect( comboProducer, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( updateType() ) );
-    connect( comboProducer, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( updateText() ) );
-    connect( comboType, TQT_SIGNAL( activated(int) ), this, TQT_SLOT( updateText() ) );
-    connect( checkEmpty, TQT_SIGNAL( clicked() ), this, TQT_SLOT( updateText() ) );
+    connect( comboProducer, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( updateType() ) );
+    connect( comboProducer, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( updateText() ) );
+    connect( comboType, TQ_SIGNAL( activated(int) ), this, TQ_SLOT( updateText() ) );
+    connect( checkEmpty, TQ_SIGNAL( clicked() ), this, TQ_SLOT( updateText() ) );
     
-    connect( buttonOk, TQT_SIGNAL( clicked() ), this, TQT_SLOT(accept() ) );
-    connect( buttonCancel, TQT_SIGNAL( clicked() ), this, TQT_SLOT(reject() ) );
-    connect( buttonOwnFormat, TQT_SIGNAL( clicked() ), this, TQT_SLOT(add() ) );
+    connect( buttonOk, TQ_SIGNAL( clicked() ), this, TQ_SLOT(accept() ) );
+    connect( buttonCancel, TQ_SIGNAL( clicked() ), this, TQ_SLOT(reject() ) );
+    connect( buttonOwnFormat, TQ_SIGNAL( clicked() ), this, TQ_SLOT(add() ) );
     fillData();
     updateType();
     updateText();
