@@ -106,7 +106,7 @@ PropertyBorder::PropertyBorder( TQWidget* parent )
     grid->addWidget( comboLine, 3, 1 );
     
     
-    connect( checkBorder, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
+    connect( checkBorder, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableControls() ) );
 }
 
 void PropertyBorder::applySettings( DocumentItem* item, KMacroCommand* command )
@@ -231,8 +231,8 @@ PropertyBarcode::PropertyBarcode( TokenProvider* token, TQWidget* parent )
     barcode = new BarcodeWidget( this, "barcode" );
     barcode->setTokenProvider( token );
 
-    //connect( this, TQT_SIGNAL( defaultClicked() ), this, TQT_SLOT( defaults() ) );
-    connect( comboComplex, TQT_SIGNAL( activated(int) ), this, TQT_SLOT(changedCombo() ) );
+    //connect( this, TQ_SIGNAL( defaultClicked() ), this, TQ_SLOT( defaults() ) );
+    connect( comboComplex, TQ_SIGNAL( activated(int) ), this, TQ_SLOT(changedCombo() ) );
     
     grid->addWidget( TextLabel1, 0, 0 );
     grid->addWidget( comboComplex, 0, 1 );
@@ -361,7 +361,7 @@ PropertySize::PropertySize( TQWidget* parent )
     
     grid->addWidget( box, 0, 0 );
     
-    connect( checkLock, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() )); 
+    connect( checkLock, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableControls() )); 
 }
 
 void PropertySize::enableControls()
@@ -502,9 +502,9 @@ PropertyImage::PropertyImage( TokenProvider* token, TQWidget* parent )
     grid->addMultiCellWidget( checkMirrorH, 5, 5, 0, 1 );
     grid->addMultiCellWidget( checkMirrorV, 6, 6, 0, 1 );
 
-    connect( radioImageExpression, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
-    connect( radioImagePath, TQT_SIGNAL( clicked() ), this, TQT_SLOT( enableControls() ) );
-    connect( buttonToken, TQT_SIGNAL( clicked() ), this, TQT_SLOT( slotTokens() ) );
+    connect( radioImageExpression, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableControls() ) );
+    connect( radioImagePath, TQ_SIGNAL( clicked() ), this, TQ_SLOT( enableControls() ) );
+    connect( buttonToken, TQ_SIGNAL( clicked() ), this, TQ_SLOT( slotTokens() ) );
 }
 
 void PropertyImage::applySettings( DocumentItem* item, KMacroCommand* command )
