@@ -32,9 +32,9 @@
 #include <tqdom.h>
 
 // KDE includes
-#include <kapplication.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdeapplication.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 
 XMLUtils::XMLUtils()
 {
@@ -297,10 +297,10 @@ void XMLUtils::writeXMLRect( TQDomElement* tag, TQRect r, TQPoint ptOrigin ) con
     tag->setAttribute( "height", r.height() );
 
     LabelUtils l;
-    tag->setAttribute( "x_mm", l.pixelToMm( r.x(), KApplication::desktop(), LabelUtils::DpiX ) );
-    tag->setAttribute( "y_mm", l.pixelToMm( r.y(), KApplication::desktop(), LabelUtils::DpiY ) );
-    tag->setAttribute( "width_mm", l.pixelToMm( r.width(), KApplication::desktop(), LabelUtils::DpiX ) );
-    tag->setAttribute( "height_mm", l.pixelToMm( r.height(), KApplication::desktop(), LabelUtils::DpiY ) );
+    tag->setAttribute( "x_mm", l.pixelToMm( r.x(), TDEApplication::desktop(), LabelUtils::DpiX ) );
+    tag->setAttribute( "y_mm", l.pixelToMm( r.y(), TDEApplication::desktop(), LabelUtils::DpiY ) );
+    tag->setAttribute( "width_mm", l.pixelToMm( r.width(), TDEApplication::desktop(), LabelUtils::DpiX ) );
+    tag->setAttribute( "height_mm", l.pixelToMm( r.height(), TDEApplication::desktop(), LabelUtils::DpiY ) );
 }*/
 
 TQRect XMLUtils::readXMLRect( TQDomElement* tag )
@@ -386,7 +386,7 @@ Definition* XMLUtils::readDefinition( TQDomElement* tag )
     m.setNumV( tag->attribute("num_v", I2S( m.numH() )).toInt() );
     m.setNumH( tag->attribute("num_h", I2S( m.numV() )).toInt() );
 
-    qDebug("Definition not found: writing to file!");
+    tqDebug("Definition not found: writing to file!");
     d->setId( Definition::write( m, type, producer ) );
         
     return d;
